Development
===========

Philosophy
----------

- Complex workflows can always be enabled through simple APIs
- With planning, simple APIs can always be constructed using clear and concise
  code
- Satisfy the general use cases, then specialize

Continuous Integration
----------------------

`Travis CI`_ is used for testing and `Codecov`_ is used for detailing code
coverage.

Documentation
-------------

Docs are hosted by `GitHub Pages`_ and are automatically built and published
by Travis after every successful commit to bitcash's ``master`` branch.

Version Scheme
--------------

BitCash tries to adhere to `semantic versioning`_ as much as possible.

.. _Travis CI: https://travis-ci.org
.. _Codecov: https://codecov.io
.. _GitHub Pages: https://pages.github.com
.. _semantic versioning: https://goo.gl/iQwd4o
